@@ -7,15 +7,15 @@
 #' @param Data a data matrix with missing values. The columns correspond to the variables and the rows to the observations.
 #'
 #' @param ntree number of trees to grow in each forest.
-#' 
+#'
 #' @param Nsets number of simulations/ data sets to be generated.
 #'
 #' @return A list containing data sets and imputed means, and imputed standard deviation.
 #'
 #' @export
-#' 
+#'
 #' @author Mohamed Soudy \email{Mohmedsoudy2009@gmail.com}
-#' 
+#'
 MERO <- function(Data, ntree = 100, Nsets = 5)
 {
   Datasest <- vector(mode = "list", length = Nsets)
@@ -24,10 +24,10 @@ MERO <- function(Data, ntree = 100, Nsets = 5)
   pb <- progress_bar$new(total = Nsets)
   Count <- 1
   x <- foreach(
-    i = 1:Nsets, 
+    i = 1:Nsets,
     .combine = 'c'
   ) %dopar% {
-    Imputed.data <- missForest(Data, ntree = 100, verbose = F)
+    Imputed.data <- missForest(Data, ntree = ntree, verbose = F)
     Datasest[[Count]] <<- Imputed.data$ximp
     Count <<- Count + 1
     Imputed.mean <<- cbind(Imputed.mean,rowMeans(Imputed.data$ximp, na.rm = T))
@@ -35,4 +35,4 @@ MERO <- function(Data, ntree = 100, Nsets = 5)
     pb$tick()
   }
   Out.data <- list(Datasest, Imputed.mean, Imputed.sd)
-}
\ No newline at end of file
+}
